\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{bthesis}[2013/12/10 Bachelorarbeit Institut f. Mathematik Univ. Innsbruck]

\RequirePackage{ifthen}
\newboolean{seminarthesis}
\setboolean{seminarthesis}{false}

\DeclareOption{sethesis}{%
	\setboolean{seminarthesis}{true}
}

\DeclareOption*{%
  \PassOptionsToClass{\CurrentOption}{scrbook}
}

\ProcessOptions\relax
\LoadClass[a4paper,ngerman,11pt,headsepline,oneside]{scrbook}

\newcommand*{\@keywords}{}%
\newcommand*{\keywords}[1]{\gdef\@keywords{#1}}

\newcommand*{\@department}{}%
\newcommand*{\department}[1]{\gdef\@department{#1}}

\newcommand*{\@supervisor}{}%
\newcommand*{\supervisor}[1]{\gdef\@supervisor{#1}}


\RequirePackage{amsthm, amsmath}

\newtheoremstyle{TheoStyle}
    {}                      % Space above
    {}                      % Space below
    {}                      % Body font
    {}                      % Indent amount
    {\bfseries\scshape}     % Theorem head font
    {\newline}              % Punctuation after theorem head
    { }                     % Space after theorem head
    {}                      % Theorem head spec

\theoremstyle{TheoStyle}
\newtheorem{satz}{Satz}[chapter]
\newtheorem{hs}[satz]{Hilfssatz}
\newtheorem{lemma}[satz]{Lemma}
\newtheorem{kor}[satz]{Korollar}
\newtheorem{pro}[satz]{Proposition}				
\newtheorem{defi}[satz]{Definition}
\newtheorem{satzdef}[satz]{Satz und Definition}
\newtheorem{defsatz}[satz]{Definition und Satz}
\newtheorem{bsp}[satz]{Beispiel}		
\newtheorem{axiom}[satz]{Axiom}

\renewcommand{\theenumi}{(\arabic{enumi})}
\renewcommand{\labelenumi}{\theenumi}
\renewcommand{\theenumii}{(\alph{enumii})}
\renewcommand{\labelenumii}{\theenumii}
\renewcommand{\labelitemi}{$\triangleright$}

\RequirePackage{hyperref}

\AtBeginDocument{
\hypersetup{
  pdftitle={\@author - \@title},
  pdfauthor={\@author},
  pdfsubject={\@title - \@author},
  pdfcreator={LaTeX2e},
  pdfproducer={\@author},
  pdfkeywords={\@keywords},
  pdfauthor={\@author},
  pdfborder=0 0 0
} 
\allowdisplaybreaks
}

\RequirePackage[format=plain,margin=10pt,font=small,sc,labelsep=space]{caption}

\RequirePackage[big]{titlesec}
\titleformat{\section}[block]{\Large\scshape\bfseries}{\thesection}{.5em}{}
\titleformat{\subsection}[block]{\large\scshape\bfseries}{\thesubsection}{.5em}{}
\titleformat{\subsubsection}[block]{\normalsize\scshape\bfseries}{\thesubsubsection}{.5em}{}

\RequirePackage{scrpage2}
\ihead{\leftmark}
\chead{}
\ohead{\pagemark}
\ifoot{} \cfoot{} \ofoot{}
\pagestyle{scrheadings}
\automark[chapter]{chapter}

\renewcommand{\headfont}{\scshape}

\renewcommand{\maketitle}{%
	\begin{titlepage}
	\vspace{2cm}
	\begin{center}
		\textbf{\textsc{\huge{\@title}}}
		\\[1.5cm]
		\ifthenelse{\boolean{seminarthesis}}{{\Large Seminararbeit}}
			{{\Large Bachelorarbeit\\[0.25cm]in der Studienrichtung Mathematik}}
	    \\[2cm]
	    \textsc{{\huge \@author}}
        \vfill
        {\large Verfasst im Rahmen der Lehrveranstaltung\\
        Seminar mit Bachelorarbeit, SE2}
    	\\[0.5cm]
    	{\Large Betreuer: \@supervisor, \@department \\[2cm]
    	Innsbruck, \@date}
	\end{center}
\end{titlepage}	
}




